# sift_rs

[![Crates.io](https://img.shields.io/crates/v/sift_rs.svg)](https://crates.io/crates/sift_rs)
[![docs.rs](https://img.shields.io/docsrs/sift_rs)](https://docs.rs/sift_rs/latest/sift_rs/)

`sift_rs` largely contains protobuf-generated code used to interact with Sift's gRPC API as well as some
utility wrappers.

See the [examples](./examples/) directory for demonstrations on how to connect to Sift and use these services.
If you're interested in streaming telemetry to Sift, see [sift_stream](../sift_stream/).
